#
# spec file for package telepathy-qt4
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         libname libtelepathy-qt4
%define         major   2
%define         farstream 1
%if 0%{?suse_version} > 1310
%define         gstreamer1 1
%else
%define         gstreamer1 0
%endif

Name:           telepathy-qt4
Version:        0.9.6.1
Release:        3.1
Summary:        Qt4 bindings for the Telepathy Library
License:        LGPL-2.1+
Group:          Development/Tools/Other
Url:            http://telepathy.freedesktop.org/
Source:         http://telepathy.freedesktop.org/releases/telepathy-qt/telepathy-qt-%{version}.tar.gz
# PATCH-FIX-UPSTREAM search-for-gstreamer1.0.diff -- searches for gstreamer1.0, which is only required for includes
Patch0:         search-for-gstreamer1.0.diff
# PATCH-FIX-UPSTREAM search-for-farstream0.2.diff -- searches for farstream0.2, instead of deprecated 0.1
Patch1:         search-for-farstream0.2.diff
# PATCH-FIX-UPSTREAM search-for-telepathy-farstream-0.4.diff -- searches for telepathy-farstream-0.4
Patch2:         search-for-telepathy-farstream-0.4.diff
# PATCH-FIX-UPSTREAM fix-farstream-compilation-with-gstreamer-1.5.1.patch mlin@suse.com
Patch3:         fix-farstream-compilation-with-gstreamer-1.5.1.patch
# PATCH-FIX-OPENSUSE fix-compilation-with-old-cmake.patch mlin@suse.com -- somehow old cmake do not like relative path
Patch4:         fix-compilation-with-old-cmake.patch
BuildRequires:  cmake
BuildRequires:  dbus-1-python
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  libqt4-devel
BuildRequires:  libxml2-devel
BuildRequires:  python-xml
BuildRequires:  pkgconfig(telepathy-glib)
%if 0%{?farstream}
%if 0%{?gstreamer1}
BuildRequires:  pkgconfig(farstream-0.2)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(telepathy-farstream)
%else
BuildRequires:  pkgconfig(farstream-0.1)
BuildRequires:  pkgconfig(gstreamer-0.10)
BuildRequires:  pkgconfig(gstreamer-plugins-base-0.10)
%if 0%{?suse_version} <= 1310
BuildRequires:  pkgconfig(telepathy-farstream-0.4)
%else
BuildRequires:  pkgconfig(telepathy-farstream)
%endif
%endif
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Telepathy-Qt4 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 4.

%package -n %{libname}-%{major}
Summary:        Library for performing syntax highlighting in Qt documents
Group:          Development/Tools/Other
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n %{libname}-%{major}
Telepathy-Qt4 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 4.

%if 0%{?farstream}
%package -n %{libname}-farstream%{major}
Summary:        Library for performing syntax highlighting in Qt documents
Group:          Development/Tools/Other
Obsoletes:      %{libname}-farsight%{major}

%description -n %{libname}-farstream%{major}
Telepathy-farstream-Qt4 is a high-level binding for Telepathy, similar to telepathy-glib but for Qt 4.
%endif

%package devel
Summary:        Header files, libraries and development documentation for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname}-%{major} = %{version}
Provides:       %{name}-service-devel-static = %{version}
%if 0%{?farstream}
Requires:       %{libname}-farstream%{major} = %{version}
%if 0%{?gstreamer1}
Requires:       pkgconfig(gstreamer-1.0)
Requires:       pkgconfig(gstreamer-plugins-base-1.0)
%else
Requires:       pkgconfig(gstreamer-0.10)
Requires:       pkgconfig(gstreamer-plugins-base-0.10)
%endif
%endif

%description devel
This package contains the header files, static libraries and development documentation for %{name}. If you like to develop programs using %{name}, you will need to install %{name}-devel.

%prep
%setup -q -n telepathy-qt-%{version}
%if 0%{?suse_version} <= 1310
%patch0 -Rp1
%patch1 -p1
%patch2 -p1
%patch4 -p1
%else
%patch3 -p1
%endif

%build
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"
if [ %{_lib} = lib64 ]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -DLIB_SUFFIX=64"
fi
mkdir build
cd build
cmake .. -DCMAKE_CXXFLAGS="%{optflags}" -DCMAKE_CFLAGS="%{optflags}" $EXTRA_FLAGS -DCMAKE_INSTALL_PREFIX=/usr \
          -DENABLE_TESTS=FALSE -DENABLE_EXAMPLES=FALSE -DENABLE_FARSIGHT=FALSE -DENABLE_FARSTREAM=TRUE -DDISABLE_WERROR=TRUE
make %{?_smp_mflags}

%install
cd build
%make_install
cd ..
%fdupes %{buildroot}

%post -n %{libname}-%{major} -p /sbin/ldconfig

%postun -n %{libname}-%{major} -p /sbin/ldconfig

%if 0%{?farstream}
%post -n %{libname}-farstream%{major} -p /sbin/ldconfig

%postun -n %{libname}-farstream%{major} -p /sbin/ldconfig
%endif

%files -n %{libname}-%{major}
%defattr(-,root,root)
%{_libdir}/libtelepathy-qt4.so.*

%if 0%{?farstream}
%files -n %{libname}-farstream%{major}
%defattr(-,root,root)
%{_libdir}/libtelepathy-qt4-farstream.so.*
%endif

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog README COPYING HACKING NEWS
%{_includedir}/telepathy-qt4/
%{_libdir}/libtelepathy-qt4.so
%{_libdir}/libtelepathy-qt4-service.a
%{_libdir}/pkgconfig/TelepathyQt4.pc
%{_libdir}/cmake/TelepathyQt4/
%{_libdir}/cmake/TelepathyQt4Service/
%{_libdir}/pkgconfig/TelepathyQt4Service.pc
%if 0%{?farstream}
%{_libdir}/cmake/TelepathyQt4Farstream/
%{_libdir}/libtelepathy-qt4-farstream.so
%{_libdir}/pkgconfig/TelepathyQt4Farstream.pc
%endif

%changelog
* Sat Nov 21 2015 mlin@suse.com
- Update to 0.9.6.1
  Fixes:
  * Fixed illegal C++ statement in one of service interfaces.
- Add fix-farstream-compilation-with-gstreamer-1.5.1.patch
  * Fix compilation with GStreamer >= 1.5.1, only apply to openSUSE
    version >= 13.1
- Add fix-compilation-with-old-cmake.patch
  * Fix build with old cmake in earlier openSUSE version
* Sat Nov 21 2015 mlin@suse.com
- Update to 0.9.6
  Enhancements:
  * Added TP_QT_VERSION and TP_QT_VERSION_CHECK macros
  - Can be used like #if (TP_QT_VERSION == TP_QT_VERSION_CHECK(0, 9, 6))
  - Absence of the TP_QT_VERSION macros indicates previous versions
    (might be useful for service bindings compatibility)
  * Added client side support for conference calls
  * Implemented numerous interfaces for service bindings
  API changes:
  * Refactored service-side bindings API
  - BaseConnection createChannel() and ensureChannel() methods
    now accept request map instead of several extracted values.
  - BaseChannel::create() arguments reordered in natural way.
  Fixes:
  * Fixed CallContent interfaces exposing (required for DTMF)
  * fd.0 #86312: Fixed condition in adaptor methods generation
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 0.9.5:
  * Added more service side bindings
  * Service bindings now enabled by default
  * Bump Farstream version
  * Allow subclass of Tp::ReceivedMessage
  * Workaround invalid channelRequests when delegating, fdo#77986
- Rebase, reorder and apply search-for-farstream0.2.diff,
  search-for-gstreamer1.0.diff and
  search-for-telepathy-farstream-0.4.diff only for
  openSUSE 13.1 and older
- Provide telepathy-qt4-service-devel-static, due to newly enabled
  service library
* Wed Jul 23 2014 hrvoje.senjan@gmail.com
- Enable farstream package for Factory/13.2 (and build with gst1.0 API)
* Thu Jun 19 2014 hrvoje.senjan@gmail.com
- Update to 0.9.4
  + Enhancements:
  * fdo#63098: add method Account::createDbusTubeRoom
  + Fixes:
  * fdo#46241: Fixed linking in farstream and farsight
  * Require tp-glib 0.18 and fix 0.19-ism
  * fdo#47647: Fixed storing avatars, so that they are not stored
    millions of times each.
  * fdo#62711: Fixed stack overflow in SimpleObserver::create
  * Fix compilation and running against release Qt5
- Drop patches included in this release:
    Fix-storing-avatars.patch
    fix-compilation-on-new-versions-of-cmake.patch
* Fri Oct 25 2013 hrvoje.senjan@gmail.com
- Build farstream for openSUSE versions older than 13.2
* Sat Oct 19 2013 hrvoje.senjan@gmail.com
- Added fix-compilation-on-new-versions-of-cmake.patch from upstream,
  fixes build with cmake >= 2.8.12
* Sat Jul 20 2013 hrvoje.senjan@gmail.com
- Added search-for-gstreamer1.0.diff, search-for-farstream0.2.diff
  and Fix-storing-avatars.patch
- Added farstream and gstreamer defines, which are disabled until
  QtGstreamer is ported to gstreamer 1.0
- Spec cleanup
* Tue Apr  2 2013 alinm.elena@gmail.com
- add patch for farstream-devel to be built
* Sat Jan  5 2013 toddrme2178@gmail.com
- Split telepathy-qt4-farstream-devel to make it easier to handle
  cases where compatible farstream versions are not available.
- Remove unused patches (don't-build-tests and gcc-4.7 fix)
* Fri Jan  4 2013 toddrme2178@gmail.com
- Disable broken farstream buildrequires for openSUSE Factory
  (12.3)
* Sun Oct  7 2012 toddrme2178@gmail.com
- Disable broken farstream buildrequires for openSUSE 12.1
* Sat Oct  6 2012 toddrme2178@gmail.com
- Fix source directory
* Tue Aug 28 2012 mlin@suse.com
- Update to 0.9.3
  * Added ClientTypes bindings to Contact.
  * Fixed deprecation macros, and added TP_QT_EXPORT_DEPRECATED.
  * Ported SimpleCallObserver to also handle Call1 calls.
  * Deprecated Farsight and StreamedMedia.
  * Introducing Telepathy-Qt-Service, a new static library that contains
    experimental service-side bindings. For the moment this exposes
    the required low-level interfaces for writing connection managers,
    as well as some basic high-level API.
  * Renamed AccountManager::accountForPath() and AccountManager::accountsForPaths()
    to accountForObjectPath() and accountsForObjectPaths() respectively,
    deprecating the old names.
  * Added bindings for Debug interface.
  * Enable several options in CMake to allow to selectively build components. In particular,
    now Farsight, Farstream, examples and tests are optional. Farsight is disabled by default.
  * fd.o #28366: Added high level bindings for DBus tubes.
  * Bugfixes
- Add ENABLE_TESTS=OFF at cmake's parameter and don't applied dont-build-tests.diff
- Don't applied telepathy-qt-0.9.0-fix-gcc47.patch due to already fixed by upstream
* Fri Mar 23 2012 cgiboudeaux@gmx.com
- Replace farsight with farstream. Both cannot be built at the same time.
* Wed Jun 15 2011 alinm.elena@gmail.com
- bumped the version string
* Mon Jan  3 2011 alinm.elena@gmail.com
- initial commit
